# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/http_connection_manager/v4alpha/http_connection_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v4alpha import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v4alpha_dot_accesslog__pb2
from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from envoy.config.core.v4alpha import protocol_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2
from envoy.config.core.v4alpha import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_substitution__format__string__pb2
from envoy.config.route.v4alpha import route_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__pb2
from envoy.config.route.v4alpha import scoped_route_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_scoped__route__pb2
from envoy.config.trace.v4alpha import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v4alpha_dot_http__tracer__pb2
from envoy.type.tracing.v3 import custom_tag_pb2 as envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import security_pb2 as udpa_dot_annotations_dot_security__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/http_connection_manager/v4alpha/http_connection_manager.proto',
  package='envoy.extensions.filters.network.http_connection_manager.v4alpha',
  syntax='proto3',
  serialized_options=b'\nNio.envoyproxy.envoy.extensions.filters.network.http_connection_manager.v4alphaB\032HttpConnectionManagerProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n^envoy/extensions/filters/network/http_connection_manager/v4alpha/http_connection_manager.proto\x12@envoy.extensions.filters.network.http_connection_manager.v4alpha\x1a.envoy/config/accesslog/v4alpha/accesslog.proto\x1a$envoy/config/core/v4alpha/base.proto\x1a-envoy/config/core/v4alpha/config_source.proto\x1a)envoy/config/core/v4alpha/extension.proto\x1a(envoy/config/core/v4alpha/protocol.proto\x1a:envoy/config/core/v4alpha/substitution_format_string.proto\x1a&envoy/config/route/v4alpha/route.proto\x1a-envoy/config/route/v4alpha/scoped_route.proto\x1a,envoy/config/trace/v4alpha/http_tracer.proto\x1a&envoy/type/tracing/v3/custom_tag.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fudpa/annotations/security.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xce$\n\x15HttpConnectionManager\x12\x7f\n\ncodec_type\x18\x01 \x01(\x0e\x32\x61.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.CodecTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12T\n\x03rds\x18\x03 \x01(\x0b\x32\x45.envoy.extensions.filters.network.http_connection_manager.v4alpha.RdsH\x00\x12\x46\n\x0croute_config\x18\x04 \x01(\x0b\x32..envoy.config.route.v4alpha.RouteConfigurationH\x00\x12g\n\rscoped_routes\x18\x1f \x01(\x0b\x32N.envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutesH\x00\x12\x62\n\x0chttp_filters\x18\x05 \x03(\x0b\x32L.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter\x12\x32\n\x0e\x61\x64\x64_user_agent\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12p\n\x07tracing\x18\x07 \x01(\x0b\x32_.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing\x12]\n\x1c\x63ommon_http_protocol_options\x18# \x01(\x0b\x32..envoy.config.core.v4alpha.HttpProtocolOptionsB\x07\x8a\x93\xb7*\x02\x08\x01\x12N\n\x15http_protocol_options\x18\x08 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http1ProtocolOptions\x12X\n\x16http2_protocol_options\x18\t \x01(\x0b\x32/.envoy.config.core.v4alpha.Http2ProtocolOptionsB\x07\x8a\x93\xb7*\x02\x08\x01\x12 \n\x0bserver_name\x18\n \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\xa2\x01\n\x1cserver_header_transformation\x18\" \x01(\x0e\x32r.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.ServerHeaderTransformationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12G\n\x16max_request_headers_kb\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18` \x00\x12?\n\x13stream_idle_timeout\x18\x18 \x01(\x0b\x32\x19.google.protobuf.DurationB\x07\x8a\x93\xb7*\x02\x08\x01\x12;\n\x0frequest_timeout\x18\x1c \x01(\x0b\x32\x19.google.protobuf.DurationB\x07\x8a\x93\xb7*\x02\x08\x01\x12K\n\x17request_headers_timeout\x18) \x01(\x0b\x32\x19.google.protobuf.DurationB\x0f\xfa\x42\x05\xaa\x01\x02\x32\x00\x8a\x93\xb7*\x02\x08\x01\x12\x30\n\rdrain_timeout\x18\x0c \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15\x64\x65layed_close_timeout\x18\x1a \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\naccess_log\x18\r \x03(\x0b\x32).envoy.config.accesslog.v4alpha.AccessLog\x12?\n\x12use_remote_address\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x07\x8a\x93\xb7*\x02\x08\x01\x12\x1c\n\x14xff_num_trusted_hops\x18\x13 \x01(\r\x12\x8e\x01\n\x17internal_address_config\x18\x19 \x01(\x0b\x32m.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.InternalAddressConfig\x12\x17\n\x0fskip_xff_append\x18\x15 \x01(\x08\x12\x0b\n\x03via\x18\x16 \x01(\t\x12\x37\n\x13generate_request_id\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12$\n\x1cpreserve_external_request_id\x18  \x01(\x08\x12)\n!always_set_request_id_in_response\x18% \x01(\x08\x12\x9f\x01\n\x1b\x66orward_client_cert_details\x18\x10 \x01(\x0e\x32p.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.ForwardClientCertDetailsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x9c\x01\n\x1fset_current_client_cert_details\x18\x11 \x01(\x0b\x32s.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails\x12\x1a\n\x12proxy_100_continue\x18\x12 \x01(\x08\x12\x39\n1represent_ipv4_remote_address_as_ipv4_mapped_ipv6\x18\x14 \x01(\x08\x12~\n\x0fupgrade_configs\x18\x17 \x03(\x0b\x32\x65.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.UpgradeConfig\x12\x32\n\x0enormalize_path\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x15\n\rmerge_slashes\x18! \x01(\x08\x12r\n\x14request_id_extension\x18$ \x01(\x0b\x32T.envoy.extensions.filters.network.http_connection_manager.v4alpha.RequestIDExtension\x12n\n\x12local_reply_config\x18& \x01(\x0b\x32R.envoy.extensions.filters.network.http_connection_manager.v4alpha.LocalReplyConfig\x12\"\n\x18strip_matching_host_port\x18\' \x01(\x08H\x01\x12\x1d\n\x13strip_any_host_port\x18* \x01(\x08H\x01\x12H\n$stream_error_on_invalid_http_message\x18( \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x9e\x04\n\x07Tracing\x12/\n\x0f\x63lient_sampling\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12/\n\x0frandom_sampling\x18\x04 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x30\n\x10overall_sampling\x18\x05 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x0f\n\x07verbose\x18\x06 \x01(\x08\x12\x39\n\x13max_path_tag_length\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x0b\x63ustom_tags\x18\x08 \x03(\x0b\x32 .envoy.type.tracing.v3.CustomTag\x12:\n\x08provider\x18\t \x01(\x0b\x32(.envoy.config.trace.v4alpha.Tracing.Http\"(\n\rOperationName\x12\x0b\n\x07INGRESS\x10\x00\x12\n\n\x06\x45GRESS\x10\x01:`\x9a\xc5\x88\x1e[\nYenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.TracingJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\x0eoperation_nameR\x18request_headers_for_tags\x1a\x9d\x01\n\x15InternalAddressConfig\x12\x14\n\x0cunix_sockets\x18\x01 \x01(\x08:n\x9a\xc5\x88\x1ei\ngenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.InternalAddressConfig\x1a\xfd\x01\n\x1bSetCurrentClientCertDetails\x12+\n\x07subject\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0c\n\x04\x63\x65rt\x18\x03 \x01(\x08\x12\r\n\x05\x63hain\x18\x06 \x01(\x08\x12\x0b\n\x03\x64ns\x18\x04 \x01(\x08\x12\x0b\n\x03uri\x18\x05 \x01(\x08:t\x9a\xc5\x88\x1eo\nmenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.SetCurrentClientCertDetailsJ\x04\x08\x02\x10\x03\x1a\x99\x02\n\rUpgradeConfig\x12\x14\n\x0cupgrade_type\x18\x01 \x01(\t\x12]\n\x07\x66ilters\x18\x02 \x03(\x0b\x32L.envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter\x12+\n\x07\x65nabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:f\x9a\xc5\x88\x1e\x61\n_envoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.UpgradeConfig\"6\n\tCodecType\x12\x08\n\x04\x41UTO\x10\x00\x12\t\n\x05HTTP1\x10\x01\x12\t\n\x05HTTP2\x10\x02\x12\t\n\x05HTTP3\x10\x03\"S\n\x1aServerHeaderTransformation\x12\r\n\tOVERWRITE\x10\x00\x12\x14\n\x10\x41PPEND_IF_ABSENT\x10\x01\x12\x10\n\x0cPASS_THROUGH\x10\x02\"y\n\x18\x46orwardClientCertDetails\x12\x0c\n\x08SANITIZE\x10\x00\x12\x10\n\x0c\x46ORWARD_ONLY\x10\x01\x12\x12\n\x0e\x41PPEND_FORWARD\x10\x02\x12\x10\n\x0cSANITIZE_SET\x10\x03\x12\x17\n\x13\x41LWAYS_FORWARD_ONLY\x10\x04:X\x9a\xc5\x88\x1eS\nQenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManagerB\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01\x42\x11\n\x0fstrip_port_modeJ\x04\x08\x1b\x10\x1cJ\x04\x08\x0b\x10\x0cR\x0cidle_timeout\"\x94\x02\n\x10LocalReplyConfig\x12\x61\n\x07mappers\x18\x01 \x03(\x0b\x32P.envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper\x12H\n\x0b\x62ody_format\x18\x02 \x01(\x0b\x32\x33.envoy.config.core.v4alpha.SubstitutionFormatString:S\x9a\xc5\x88\x1eN\nLenvoy.extensions.filters.network.http_connection_manager.v3.LocalReplyConfig\"\xc7\x03\n\x0eResponseMapper\x12I\n\x06\x66ilter\x18\x01 \x01(\x0b\x32/.envoy.config.accesslog.v4alpha.AccessLogFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12>\n\x0bstatus_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01\x12\x33\n\x04\x62ody\x18\x03 \x01(\x0b\x32%.envoy.config.core.v4alpha.DataSource\x12Q\n\x14\x62ody_format_override\x18\x04 \x01(\x0b\x32\x33.envoy.config.core.v4alpha.SubstitutionFormatString\x12O\n\x0eheaders_to_add\x18\x05 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07:Q\x9a\xc5\x88\x1eL\nJenvoy.extensions.filters.network.http_connection_manager.v3.ResponseMapper\"\xb2\x01\n\x03Rds\x12H\n\rconfig_source\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11route_config_name\x18\x02 \x01(\t:F\x9a\xc5\x88\x1e\x41\n?envoy.extensions.filters.network.http_connection_manager.v3.Rds\"\xe6\x01\n\x1dScopedRouteConfigurationsList\x12\x63\n\x1bscoped_route_configurations\x18\x01 \x03(\x0b\x32\x34.envoy.config.route.v4alpha.ScopedRouteConfigurationB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:`\x9a\xc5\x88\x1e[\nYenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRouteConfigurationsList\"\xfc\r\n\x0cScopedRoutes\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x83\x01\n\x11scope_key_builder\x18\x02 \x01(\x0b\x32^.envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilderB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12L\n\x11rds_config_source\x18\x03 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x8b\x01\n scoped_route_configurations_list\x18\x04 \x01(\x0b\x32_.envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRouteConfigurationsListH\x00\x12\x61\n\nscoped_rds\x18\x05 \x01(\x0b\x32K.envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRdsH\x00\x1a\xa5\t\n\x0fScopeKeyBuilder\x12\x8b\x01\n\tfragments\x18\x01 \x03(\x0b\x32n.envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilderB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xa2\x07\n\x0f\x46ragmentBuilder\x12\xa6\x01\n\x16header_value_extractor\x18\x01 \x01(\x0b\x32\x83\x01.envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractorH\x00\x1a\xe7\x04\n\x14HeaderValueExtractor\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x19\n\x11\x65lement_separator\x18\x02 \x01(\t\x12\x0f\n\x05index\x18\x03 \x01(\rH\x00\x12\xa1\x01\n\x07\x65lement\x18\x04 \x01(\x0b\x32\x8d\x01.envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElementH\x00\x1a\xd0\x01\n\tKvElement\x12\x1a\n\tseparator\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:\x90\x01\x9a\xc5\x88\x1e\x8a\x01\n\x87\x01\x65nvoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement:\x84\x01\x9a\xc5\x88\x1e\x7f\n}envoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractorB\x0e\n\x0c\x65xtract_type:o\x9a\xc5\x88\x1ej\nhenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder.FragmentBuilderB\x0b\n\x04type\x12\x03\xf8\x42\x01:_\x9a\xc5\x88\x1eZ\nXenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder:O\x9a\xc5\x88\x1eJ\nHenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutesB\x17\n\x10\x63onfig_specifier\x12\x03\xf8\x42\x01\"\xae\x01\n\tScopedRds\x12S\n\x18scoped_rds_config_source\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:L\x9a\xc5\x88\x1eG\nEenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRds\"\xa6\x02\n\nHttpFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12L\n\x10\x63onfig_discovery\x18\x05 \x01(\x0b\x32\x30.envoy.config.core.v4alpha.ExtensionConfigSourceH\x00\x12\x13\n\x0bis_optional\x18\x06 \x01(\x08:M\x9a\xc5\x88\x1eH\nFenvoy.extensions.filters.network.http_connection_manager.v3.HttpFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04J\x04\x08\x02\x10\x03R\x06\x63onfig\"\x97\x01\n\x12RequestIDExtension\x12*\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any:U\x9a\xc5\x88\x1eP\nNenvoy.extensions.filters.network.http_connection_manager.v3.RequestIDExtensionBv\nNio.envoyproxy.envoy.extensions.filters.network.http_connection_manager.v4alphaB\x1aHttpConnectionManagerProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_accesslog_dot_v4alpha_dot_accesslog__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_substitution__format__string__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_scoped__route__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v4alpha_dot_http__tracer__pb2.DESCRIPTOR,envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_security__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME = _descriptor.EnumDescriptor(
  name='OperationName',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.OperationName',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INGRESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EGRESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4231,
  serialized_end=4271,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME)

_HTTPCONNECTIONMANAGER_CODECTYPE = _descriptor.EnumDescriptor(
  name='CodecType',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.CodecType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP3', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5125,
  serialized_end=5179,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_CODECTYPE)

_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION = _descriptor.EnumDescriptor(
  name='ServerHeaderTransformation',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.ServerHeaderTransformation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OVERWRITE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPEND_IF_ABSENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASS_THROUGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5181,
  serialized_end=5264,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION)

_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS = _descriptor.EnumDescriptor(
  name='ForwardClientCertDetails',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.ForwardClientCertDetails',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SANITIZE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORWARD_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPEND_FORWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SANITIZE_SET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALWAYS_FORWARD_ONLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5266,
  serialized_end=5387,
)
_sym_db.RegisterEnumDescriptor(_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS)


_HTTPCONNECTIONMANAGER_TRACING = _descriptor.Descriptor(
  name='Tracing',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_sampling', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.client_sampling', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_sampling', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.random_sampling', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall_sampling', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.overall_sampling', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verbose', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.verbose', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_path_tag_length', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.max_path_tag_length', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_tags', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.custom_tags', index=5,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing.provider', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME,
  ],
  serialized_options=b'\232\305\210\036[\nYenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.Tracing',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3881,
  serialized_end=4423,
)

_HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG = _descriptor.Descriptor(
  name='InternalAddressConfig',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.InternalAddressConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unix_sockets', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.InternalAddressConfig.unix_sockets', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036i\ngenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.InternalAddressConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4426,
  serialized_end=4583,
)

_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS = _descriptor.Descriptor(
  name='SetCurrentClientCertDetails',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails.subject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cert', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails.cert', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails.chain', index=2,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails.dns', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails.uri', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036o\nmenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.SetCurrentClientCertDetails',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4586,
  serialized_end=4839,
)

_HTTPCONNECTIONMANAGER_UPGRADECONFIG = _descriptor.Descriptor(
  name='UpgradeConfig',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.UpgradeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upgrade_type', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.UpgradeConfig.upgrade_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.UpgradeConfig.filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.UpgradeConfig.enabled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036a\n_envoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager.UpgradeConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4842,
  serialized_end=5123,
)

_HTTPCONNECTIONMANAGER = _descriptor.Descriptor(
  name='HttpConnectionManager',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec_type', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.codec_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.stat_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rds', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.rds', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.route_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_routes', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.scoped_routes', index=4,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_filters', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.http_filters', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_user_agent', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.add_user_agent', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracing', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.tracing', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='common_http_protocol_options', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.common_http_protocol_options', index=8,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\223\267*\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.http_protocol_options', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.http2_protocol_options', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\223\267*\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_name', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.server_name', index=11,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_header_transformation', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.server_header_transformation', index=12,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_request_headers_kb', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.max_request_headers_kb', index=13,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030` \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_idle_timeout', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.stream_idle_timeout', index=14,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\223\267*\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_timeout', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.request_timeout', index=15,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\223\267*\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_timeout', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.request_headers_timeout', index=16,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\0022\000\212\223\267*\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drain_timeout', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.drain_timeout', index=17,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_close_timeout', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.delayed_close_timeout', index=18,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_log', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.access_log', index=19,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_remote_address', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.use_remote_address', index=20,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\223\267*\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xff_num_trusted_hops', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.xff_num_trusted_hops', index=21,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_address_config', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.internal_address_config', index=22,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_xff_append', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.skip_xff_append', index=23,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='via', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.via', index=24,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generate_request_id', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.generate_request_id', index=25,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preserve_external_request_id', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.preserve_external_request_id', index=26,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_set_request_id_in_response', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.always_set_request_id_in_response', index=27,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_client_cert_details', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.forward_client_cert_details', index=28,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_current_client_cert_details', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.set_current_client_cert_details', index=29,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_100_continue', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.proxy_100_continue', index=30,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='represent_ipv4_remote_address_as_ipv4_mapped_ipv6', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.represent_ipv4_remote_address_as_ipv4_mapped_ipv6', index=31,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upgrade_configs', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.upgrade_configs', index=32,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalize_path', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.normalize_path', index=33,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merge_slashes', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.merge_slashes', index=34,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id_extension', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.request_id_extension', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_reply_config', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.local_reply_config', index=36,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strip_matching_host_port', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.strip_matching_host_port', index=37,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strip_any_host_port', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.strip_any_host_port', index=38,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_error_on_invalid_http_message', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.stream_error_on_invalid_http_message', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPCONNECTIONMANAGER_TRACING, _HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG, _HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS, _HTTPCONNECTIONMANAGER_UPGRADECONFIG, ],
  enum_types=[
    _HTTPCONNECTIONMANAGER_CODECTYPE,
    _HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION,
    _HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS,
  ],
  serialized_options=b'\232\305\210\036S\nQenvoy.extensions.filters.network.http_connection_manager.v3.HttpConnectionManager',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='route_specifier', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.route_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
    _descriptor.OneofDescriptor(
      name='strip_port_mode', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.strip_port_mode',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=860,
  serialized_end=5546,
)


_LOCALREPLYCONFIG = _descriptor.Descriptor(
  name='LocalReplyConfig',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.LocalReplyConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mappers', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.LocalReplyConfig.mappers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_format', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.LocalReplyConfig.body_format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036N\nLenvoy.extensions.filters.network.http_connection_manager.v3.LocalReplyConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5549,
  serialized_end=5825,
)


_RESPONSEMAPPER = _descriptor.Descriptor(
  name='ResponseMapper',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper.status_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\020\330\004(\310\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper.body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_format_override', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper.body_format_override', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_to_add', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper.headers_to_add', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036L\nJenvoy.extensions.filters.network.http_connection_manager.v3.ResponseMapper',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5828,
  serialized_end=6283,
)


_RDS = _descriptor.Descriptor(
  name='Rds',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.Rds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_source', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.Rds.config_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config_name', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.Rds.route_config_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.extensions.filters.network.http_connection_manager.v3.Rds',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6286,
  serialized_end=6464,
)


_SCOPEDROUTECONFIGURATIONSLIST = _descriptor.Descriptor(
  name='ScopedRouteConfigurationsList',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRouteConfigurationsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoped_route_configurations', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRouteConfigurationsList.scoped_route_configurations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036[\nYenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRouteConfigurationsList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6467,
  serialized_end=6697,
)


_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT = _descriptor.Descriptor(
  name='KvElement',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='separator', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement.separator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\212\001\n\207\001envoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7800,
  serialized_end=8008,
)

_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR = _descriptor.Descriptor(
  name='HeaderValueExtractor',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_separator', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.element_separator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.element', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\177\n}envoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='extract_type', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.extract_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7544,
  serialized_end=8159,
)

_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER = _descriptor.Descriptor(
  name='FragmentBuilder',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_value_extractor', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.header_value_extractor', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036j\nhenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=7355,
  serialized_end=8285,
)

_SCOPEDROUTES_SCOPEKEYBUILDER = _descriptor.Descriptor(
  name='ScopeKeyBuilder',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fragments', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.fragments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036Z\nXenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes.ScopeKeyBuilder',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7193,
  serialized_end=8382,
)

_SCOPEDROUTES = _descriptor.Descriptor(
  name='ScopedRoutes',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope_key_builder', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.scope_key_builder', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rds_config_source', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.rds_config_source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_route_configurations_list', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.scoped_route_configurations_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_rds', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.scoped_rds', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOPEDROUTES_SCOPEKEYBUILDER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036J\nHenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRoutes',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_specifier', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.config_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=6700,
  serialized_end=8488,
)


_SCOPEDRDS = _descriptor.Descriptor(
  name='ScopedRds',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoped_rds_config_source', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRds.scoped_rds_config_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036G\nEenvoy.extensions.filters.network.http_connection_manager.v3.ScopedRds',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8491,
  serialized_end=8665,
)


_HTTPFILTER = _descriptor.Descriptor(
  name='HttpFilter',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter.typed_config', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_discovery', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter.config_discovery', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_optional', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter.is_optional', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.extensions.filters.network.http_connection_manager.v3.HttpFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8668,
  serialized_end=8962,
)


_REQUESTIDEXTENSION = _descriptor.Descriptor(
  name='RequestIDExtension',
  full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.RequestIDExtension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.filters.network.http_connection_manager.v4alpha.RequestIDExtension.typed_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036P\nNenvoy.extensions.filters.network.http_connection_manager.v3.RequestIDExtension',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8965,
  serialized_end=9116,
)

_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['client_sampling'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['random_sampling'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['overall_sampling'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['max_path_tag_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['custom_tags'].message_type = envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2._CUSTOMTAG
_HTTPCONNECTIONMANAGER_TRACING.fields_by_name['provider'].message_type = envoy_dot_config_dot_trace_dot_v4alpha_dot_http__tracer__pb2._TRACING_HTTP
_HTTPCONNECTIONMANAGER_TRACING.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME.containing_type = _HTTPCONNECTIONMANAGER_TRACING
_HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS.fields_by_name['subject'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_UPGRADECONFIG.fields_by_name['filters'].message_type = _HTTPFILTER
_HTTPCONNECTIONMANAGER_UPGRADECONFIG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER_UPGRADECONFIG.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER.fields_by_name['codec_type'].enum_type = _HTTPCONNECTIONMANAGER_CODECTYPE
_HTTPCONNECTIONMANAGER.fields_by_name['rds'].message_type = _RDS
_HTTPCONNECTIONMANAGER.fields_by_name['route_config'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__pb2._ROUTECONFIGURATION
_HTTPCONNECTIONMANAGER.fields_by_name['scoped_routes'].message_type = _SCOPEDROUTES
_HTTPCONNECTIONMANAGER.fields_by_name['http_filters'].message_type = _HTTPFILTER
_HTTPCONNECTIONMANAGER.fields_by_name['add_user_agent'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['tracing'].message_type = _HTTPCONNECTIONMANAGER_TRACING
_HTTPCONNECTIONMANAGER.fields_by_name['common_http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTPPROTOCOLOPTIONS
_HTTPCONNECTIONMANAGER.fields_by_name['http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPCONNECTIONMANAGER.fields_by_name['http2_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPCONNECTIONMANAGER.fields_by_name['server_header_transformation'].enum_type = _HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION
_HTTPCONNECTIONMANAGER.fields_by_name['max_request_headers_kb'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPCONNECTIONMANAGER.fields_by_name['stream_idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['request_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['request_headers_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['drain_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['delayed_close_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPCONNECTIONMANAGER.fields_by_name['access_log'].message_type = envoy_dot_config_dot_accesslog_dot_v4alpha_dot_accesslog__pb2._ACCESSLOG
_HTTPCONNECTIONMANAGER.fields_by_name['use_remote_address'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['internal_address_config'].message_type = _HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG
_HTTPCONNECTIONMANAGER.fields_by_name['generate_request_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['forward_client_cert_details'].enum_type = _HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS
_HTTPCONNECTIONMANAGER.fields_by_name['set_current_client_cert_details'].message_type = _HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS
_HTTPCONNECTIONMANAGER.fields_by_name['upgrade_configs'].message_type = _HTTPCONNECTIONMANAGER_UPGRADECONFIG
_HTTPCONNECTIONMANAGER.fields_by_name['normalize_path'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER.fields_by_name['request_id_extension'].message_type = _REQUESTIDEXTENSION
_HTTPCONNECTIONMANAGER.fields_by_name['local_reply_config'].message_type = _LOCALREPLYCONFIG
_HTTPCONNECTIONMANAGER.fields_by_name['stream_error_on_invalid_http_message'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTPCONNECTIONMANAGER_CODECTYPE.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS.containing_type = _HTTPCONNECTIONMANAGER
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['rds'])
_HTTPCONNECTIONMANAGER.fields_by_name['rds'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['route_config'])
_HTTPCONNECTIONMANAGER.fields_by_name['route_config'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['scoped_routes'])
_HTTPCONNECTIONMANAGER.fields_by_name['scoped_routes'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']
_HTTPCONNECTIONMANAGER.oneofs_by_name['strip_port_mode'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['strip_matching_host_port'])
_HTTPCONNECTIONMANAGER.fields_by_name['strip_matching_host_port'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['strip_port_mode']
_HTTPCONNECTIONMANAGER.oneofs_by_name['strip_port_mode'].fields.append(
  _HTTPCONNECTIONMANAGER.fields_by_name['strip_any_host_port'])
_HTTPCONNECTIONMANAGER.fields_by_name['strip_any_host_port'].containing_oneof = _HTTPCONNECTIONMANAGER.oneofs_by_name['strip_port_mode']
_LOCALREPLYCONFIG.fields_by_name['mappers'].message_type = _RESPONSEMAPPER
_LOCALREPLYCONFIG.fields_by_name['body_format'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_substitution__format__string__pb2._SUBSTITUTIONFORMATSTRING
_RESPONSEMAPPER.fields_by_name['filter'].message_type = envoy_dot_config_dot_accesslog_dot_v4alpha_dot_accesslog__pb2._ACCESSLOGFILTER
_RESPONSEMAPPER.fields_by_name['status_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_RESPONSEMAPPER.fields_by_name['body'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._DATASOURCE
_RESPONSEMAPPER.fields_by_name['body_format_override'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_substitution__format__string__pb2._SUBSTITUTIONFORMATSTRING
_RESPONSEMAPPER.fields_by_name['headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_RDS.fields_by_name['config_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_SCOPEDROUTECONFIGURATIONSLIST.fields_by_name['scoped_route_configurations'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_scoped__route__pb2._SCOPEDROUTECONFIGURATION
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.containing_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['element'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.containing_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type'].fields.append(
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['index'])
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['index'].containing_oneof = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type']
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type'].fields.append(
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['element'])
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['element'].containing_oneof = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.oneofs_by_name['extract_type']
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.fields_by_name['header_value_extractor'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.containing_type = _SCOPEDROUTES_SCOPEKEYBUILDER
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type'].fields.append(
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.fields_by_name['header_value_extractor'])
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.fields_by_name['header_value_extractor'].containing_oneof = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type']
_SCOPEDROUTES_SCOPEKEYBUILDER.fields_by_name['fragments'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER
_SCOPEDROUTES_SCOPEKEYBUILDER.containing_type = _SCOPEDROUTES
_SCOPEDROUTES.fields_by_name['scope_key_builder'].message_type = _SCOPEDROUTES_SCOPEKEYBUILDER
_SCOPEDROUTES.fields_by_name['rds_config_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_SCOPEDROUTES.fields_by_name['scoped_route_configurations_list'].message_type = _SCOPEDROUTECONFIGURATIONSLIST
_SCOPEDROUTES.fields_by_name['scoped_rds'].message_type = _SCOPEDRDS
_SCOPEDROUTES.oneofs_by_name['config_specifier'].fields.append(
  _SCOPEDROUTES.fields_by_name['scoped_route_configurations_list'])
_SCOPEDROUTES.fields_by_name['scoped_route_configurations_list'].containing_oneof = _SCOPEDROUTES.oneofs_by_name['config_specifier']
_SCOPEDROUTES.oneofs_by_name['config_specifier'].fields.append(
  _SCOPEDROUTES.fields_by_name['scoped_rds'])
_SCOPEDROUTES.fields_by_name['scoped_rds'].containing_oneof = _SCOPEDROUTES.oneofs_by_name['config_specifier']
_SCOPEDRDS.fields_by_name['scoped_rds_config_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
_HTTPFILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_HTTPFILTER.fields_by_name['config_discovery'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._EXTENSIONCONFIGSOURCE
_HTTPFILTER.oneofs_by_name['config_type'].fields.append(
  _HTTPFILTER.fields_by_name['typed_config'])
_HTTPFILTER.fields_by_name['typed_config'].containing_oneof = _HTTPFILTER.oneofs_by_name['config_type']
_HTTPFILTER.oneofs_by_name['config_type'].fields.append(
  _HTTPFILTER.fields_by_name['config_discovery'])
_HTTPFILTER.fields_by_name['config_discovery'].containing_oneof = _HTTPFILTER.oneofs_by_name['config_type']
_REQUESTIDEXTENSION.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['HttpConnectionManager'] = _HTTPCONNECTIONMANAGER
DESCRIPTOR.message_types_by_name['LocalReplyConfig'] = _LOCALREPLYCONFIG
DESCRIPTOR.message_types_by_name['ResponseMapper'] = _RESPONSEMAPPER
DESCRIPTOR.message_types_by_name['Rds'] = _RDS
DESCRIPTOR.message_types_by_name['ScopedRouteConfigurationsList'] = _SCOPEDROUTECONFIGURATIONSLIST
DESCRIPTOR.message_types_by_name['ScopedRoutes'] = _SCOPEDROUTES
DESCRIPTOR.message_types_by_name['ScopedRds'] = _SCOPEDRDS
DESCRIPTOR.message_types_by_name['HttpFilter'] = _HTTPFILTER
DESCRIPTOR.message_types_by_name['RequestIDExtension'] = _REQUESTIDEXTENSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpConnectionManager = _reflection.GeneratedProtocolMessageType('HttpConnectionManager', (_message.Message,), {

  'Tracing' : _reflection.GeneratedProtocolMessageType('Tracing', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_TRACING,
    '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.Tracing)
    })
  ,

  'InternalAddressConfig' : _reflection.GeneratedProtocolMessageType('InternalAddressConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG,
    '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.InternalAddressConfig)
    })
  ,

  'SetCurrentClientCertDetails' : _reflection.GeneratedProtocolMessageType('SetCurrentClientCertDetails', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS,
    '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.SetCurrentClientCertDetails)
    })
  ,

  'UpgradeConfig' : _reflection.GeneratedProtocolMessageType('UpgradeConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPCONNECTIONMANAGER_UPGRADECONFIG,
    '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager.UpgradeConfig)
    })
  ,
  'DESCRIPTOR' : _HTTPCONNECTIONMANAGER,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpConnectionManager)
  })
_sym_db.RegisterMessage(HttpConnectionManager)
_sym_db.RegisterMessage(HttpConnectionManager.Tracing)
_sym_db.RegisterMessage(HttpConnectionManager.InternalAddressConfig)
_sym_db.RegisterMessage(HttpConnectionManager.SetCurrentClientCertDetails)
_sym_db.RegisterMessage(HttpConnectionManager.UpgradeConfig)

LocalReplyConfig = _reflection.GeneratedProtocolMessageType('LocalReplyConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOCALREPLYCONFIG,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.LocalReplyConfig)
  })
_sym_db.RegisterMessage(LocalReplyConfig)

ResponseMapper = _reflection.GeneratedProtocolMessageType('ResponseMapper', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEMAPPER,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ResponseMapper)
  })
_sym_db.RegisterMessage(ResponseMapper)

Rds = _reflection.GeneratedProtocolMessageType('Rds', (_message.Message,), {
  'DESCRIPTOR' : _RDS,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.Rds)
  })
_sym_db.RegisterMessage(Rds)

ScopedRouteConfigurationsList = _reflection.GeneratedProtocolMessageType('ScopedRouteConfigurationsList', (_message.Message,), {
  'DESCRIPTOR' : _SCOPEDROUTECONFIGURATIONSLIST,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRouteConfigurationsList)
  })
_sym_db.RegisterMessage(ScopedRouteConfigurationsList)

ScopedRoutes = _reflection.GeneratedProtocolMessageType('ScopedRoutes', (_message.Message,), {

  'ScopeKeyBuilder' : _reflection.GeneratedProtocolMessageType('ScopeKeyBuilder', (_message.Message,), {

    'FragmentBuilder' : _reflection.GeneratedProtocolMessageType('FragmentBuilder', (_message.Message,), {

      'HeaderValueExtractor' : _reflection.GeneratedProtocolMessageType('HeaderValueExtractor', (_message.Message,), {

        'KvElement' : _reflection.GeneratedProtocolMessageType('KvElement', (_message.Message,), {
          'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT,
          '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
          # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement)
          })
        ,
        'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR,
        '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
        # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor)
        })
      ,
      'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER,
      '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
      # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder)
      })
    ,
    'DESCRIPTOR' : _SCOPEDROUTES_SCOPEKEYBUILDER,
    '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes.ScopeKeyBuilder)
    })
  ,
  'DESCRIPTOR' : _SCOPEDROUTES,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRoutes)
  })
_sym_db.RegisterMessage(ScopedRoutes)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder.FragmentBuilder)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor)
_sym_db.RegisterMessage(ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElement)

ScopedRds = _reflection.GeneratedProtocolMessageType('ScopedRds', (_message.Message,), {
  'DESCRIPTOR' : _SCOPEDRDS,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.ScopedRds)
  })
_sym_db.RegisterMessage(ScopedRds)

HttpFilter = _reflection.GeneratedProtocolMessageType('HttpFilter', (_message.Message,), {
  'DESCRIPTOR' : _HTTPFILTER,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.HttpFilter)
  })
_sym_db.RegisterMessage(HttpFilter)

RequestIDExtension = _reflection.GeneratedProtocolMessageType('RequestIDExtension', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTIDEXTENSION,
  '__module__' : 'envoy.extensions.filters.network.http_connection_manager.v4alpha.http_connection_manager_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.http_connection_manager.v4alpha.RequestIDExtension)
  })
_sym_db.RegisterMessage(RequestIDExtension)


DESCRIPTOR._options = None
_HTTPCONNECTIONMANAGER_TRACING._options = None
_HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG._options = None
_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS._options = None
_HTTPCONNECTIONMANAGER_UPGRADECONFIG._options = None
_HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['codec_type']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['stat_prefix']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['common_http_protocol_options']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['http2_protocol_options']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['server_name']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['server_header_transformation']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['max_request_headers_kb']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['stream_idle_timeout']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['request_timeout']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['request_headers_timeout']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['use_remote_address']._options = None
_HTTPCONNECTIONMANAGER.fields_by_name['forward_client_cert_details']._options = None
_HTTPCONNECTIONMANAGER._options = None
_LOCALREPLYCONFIG._options = None
_RESPONSEMAPPER.fields_by_name['filter']._options = None
_RESPONSEMAPPER.fields_by_name['status_code']._options = None
_RESPONSEMAPPER.fields_by_name['headers_to_add']._options = None
_RESPONSEMAPPER._options = None
_RDS.fields_by_name['config_source']._options = None
_RDS._options = None
_SCOPEDROUTECONFIGURATIONSLIST.fields_by_name['scoped_route_configurations']._options = None
_SCOPEDROUTECONFIGURATIONSLIST._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['separator']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['key']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['name']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER.fields_by_name['fragments']._options = None
_SCOPEDROUTES_SCOPEKEYBUILDER._options = None
_SCOPEDROUTES.oneofs_by_name['config_specifier']._options = None
_SCOPEDROUTES.fields_by_name['name']._options = None
_SCOPEDROUTES.fields_by_name['scope_key_builder']._options = None
_SCOPEDROUTES.fields_by_name['rds_config_source']._options = None
_SCOPEDROUTES._options = None
_SCOPEDRDS.fields_by_name['scoped_rds_config_source']._options = None
_SCOPEDRDS._options = None
_HTTPFILTER.fields_by_name['name']._options = None
_HTTPFILTER._options = None
_REQUESTIDEXTENSION._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/v4alpha/dubbo_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.dubbo_proxy.v4alpha import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_dubbo__proxy_dot_v4alpha_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/dubbo_proxy/v4alpha/dubbo_proxy.proto',
  package='envoy.extensions.filters.network.dubbo_proxy.v4alpha',
  syntax='proto3',
  serialized_options=b'\nBio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v4alphaB\017DubboProxyProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nFenvoy/extensions/filters/network/dubbo_proxy/v4alpha/dubbo_proxy.proto\x12\x34\x65nvoy.extensions.filters.network.dubbo_proxy.v4alpha\x1a@envoy/extensions/filters/network/dubbo_proxy/v4alpha/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfb\x03\n\nDubboProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x63\n\rprotocol_type\x18\x02 \x01(\x0e\x32\x42.envoy.extensions.filters.network.dubbo_proxy.v4alpha.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12m\n\x12serialization_type\x18\x03 \x01(\x0e\x32G.envoy.extensions.filters.network.dubbo_proxy.v4alpha.SerializationTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12^\n\x0croute_config\x18\x04 \x03(\x0b\x32H.envoy.extensions.filters.network.dubbo_proxy.v4alpha.RouteConfiguration\x12X\n\rdubbo_filters\x18\x05 \x03(\x0b\x32\x41.envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter:A\x9a\xc5\x88\x1e<\n:envoy.extensions.filters.network.dubbo_proxy.v3.DubboProxy\"\x8e\x01\n\x0b\x44ubboFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:B\x9a\xc5\x88\x1e=\n;envoy.extensions.filters.network.dubbo_proxy.v3.DubboFilter*\x19\n\x0cProtocolType\x12\t\n\x05\x44ubbo\x10\x00*!\n\x11SerializationType\x12\x0c\n\x08Hessian2\x10\x00\x42_\nBio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v4alphaB\x0f\x44ubboProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_filters_dot_network_dot_dubbo__proxy_dot_v4alpha_dot_route__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_PROTOCOLTYPE = _descriptor.EnumDescriptor(
  name='ProtocolType',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.ProtocolType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Dubbo', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=967,
  serialized_end=992,
)
_sym_db.RegisterEnumDescriptor(_PROTOCOLTYPE)

ProtocolType = enum_type_wrapper.EnumTypeWrapper(_PROTOCOLTYPE)
_SERIALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='SerializationType',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.SerializationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Hessian2', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=994,
  serialized_end=1027,
)
_sym_db.RegisterEnumDescriptor(_SERIALIZATIONTYPE)

SerializationType = enum_type_wrapper.EnumTypeWrapper(_SERIALIZATIONTYPE)
Dubbo = 0
Hessian2 = 0



_DUBBOPROXY = _descriptor.Descriptor(
  name='DubboProxy',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_type', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.protocol_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialization_type', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.serialization_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.route_config', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dubbo_filters', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.dubbo_filters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036<\n:envoy.extensions.filters.network.dubbo_proxy.v3.DubboProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=820,
)


_DUBBOFILTER = _descriptor.Descriptor(
  name='DubboFilter',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.extensions.filters.network.dubbo_proxy.v3.DubboFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=965,
)

_DUBBOPROXY.fields_by_name['protocol_type'].enum_type = _PROTOCOLTYPE
_DUBBOPROXY.fields_by_name['serialization_type'].enum_type = _SERIALIZATIONTYPE
_DUBBOPROXY.fields_by_name['route_config'].message_type = envoy_dot_extensions_dot_filters_dot_network_dot_dubbo__proxy_dot_v4alpha_dot_route__pb2._ROUTECONFIGURATION
_DUBBOPROXY.fields_by_name['dubbo_filters'].message_type = _DUBBOFILTER
_DUBBOFILTER.fields_by_name['config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['DubboProxy'] = _DUBBOPROXY
DESCRIPTOR.message_types_by_name['DubboFilter'] = _DUBBOFILTER
DESCRIPTOR.enum_types_by_name['ProtocolType'] = _PROTOCOLTYPE
DESCRIPTOR.enum_types_by_name['SerializationType'] = _SERIALIZATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DubboProxy = _reflection.GeneratedProtocolMessageType('DubboProxy', (_message.Message,), {
  'DESCRIPTOR' : _DUBBOPROXY,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v4alpha.dubbo_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy)
  })
_sym_db.RegisterMessage(DubboProxy)

DubboFilter = _reflection.GeneratedProtocolMessageType('DubboFilter', (_message.Message,), {
  'DESCRIPTOR' : _DUBBOFILTER,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v4alpha.dubbo_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter)
  })
_sym_db.RegisterMessage(DubboFilter)


DESCRIPTOR._options = None
_DUBBOPROXY.fields_by_name['stat_prefix']._options = None
_DUBBOPROXY.fields_by_name['protocol_type']._options = None
_DUBBOPROXY.fields_by_name['serialization_type']._options = None
_DUBBOPROXY._options = None
_DUBBOFILTER.fields_by_name['name']._options = None
_DUBBOFILTER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v4alpha/quic_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v4alpha/quic_config.proto',
  package='envoy.config.listener.v4alpha',
  syntax='proto3',
  serialized_options=b'\n+io.envoyproxy.envoy.config.listener.v4alphaB\017QuicConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/envoy/config/listener/v4alpha/quic_config.proto\x12\x1d\x65nvoy.config.listener.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xb6\x02\n\x13QuicProtocolOptions\x12<\n\x16max_concurrent_streams\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\x0cidle_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x18\x63rypto_handshake_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12>\n\x07\x65nabled\x18\x04 \x01(\x0b\x32-.envoy.config.core.v4alpha.RuntimeFeatureFlag:3\x9a\xc5\x88\x1e.\n,envoy.config.listener.v3.QuicProtocolOptionsBH\n+io.envoyproxy.envoy.config.listener.v4alphaB\x0fQuicConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_QUICPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='QuicProtocolOptions',
  full_name='envoy.config.listener.v4alpha.QuicProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_concurrent_streams', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.max_concurrent_streams', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.idle_timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crypto_handshake_timeout', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.crypto_handshake_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.enabled', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.listener.v3.QuicProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=561,
)

_QUICPROTOCOLOPTIONS.fields_by_name['max_concurrent_streams'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_QUICPROTOCOLOPTIONS.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_QUICPROTOCOLOPTIONS.fields_by_name['crypto_handshake_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_QUICPROTOCOLOPTIONS.fields_by_name['enabled'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFEATUREFLAG
DESCRIPTOR.message_types_by_name['QuicProtocolOptions'] = _QUICPROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuicProtocolOptions = _reflection.GeneratedProtocolMessageType('QuicProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _QUICPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.listener.v4alpha.quic_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v4alpha.QuicProtocolOptions)
  })
_sym_db.RegisterMessage(QuicProtocolOptions)


DESCRIPTOR._options = None
_QUICPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)
